aboutsummaryrefslogtreecommitdiff
path: root/src/hydrilla/builder/local_apt.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/hydrilla/builder/local_apt.py')
-rw-r--r--src/hydrilla/builder/local_apt.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/hydrilla/builder/local_apt.py b/src/hydrilla/builder/local_apt.py
index eee028d..1bdc347 100644
--- a/src/hydrilla/builder/local_apt.py
+++ b/src/hydrilla/builder/local_apt.py
@@ -167,6 +167,7 @@ def apt_conf(directory: Path) -> str:
spaces.
"""
return f'''
+Architecture "amd64";
Dir "{directory}";
Dir::State "{directory}/var/lib/apt";
Dir::State::status "{directory}/var/lib/dpkg/status";
@@ -290,9 +291,9 @@ def download_apt_packages(list: SourcesList, keys: [str], packages: [str],
Set up a local APT, update it using the specified sources.list configuration
and use it to download the specified packages.
This function downloads a .deb file of the packages matching the current
architecture (which includes packages with architecture 'all') as well as
- all theis corresponding source package files and (if requested) the debs
+ all their corresponding source package files and (if requested) the debs
and source files of all their declared dependencies.
Return value is a list of names of all downloaded files.
@@ -290,9 +291,9 @@ def download_apt_packages(list: SourcesList, keys: [str], packages: [str],
Set up a local APT, update it using the specified sources.list configuration
and use it to download the specified packages.
- This function downloads a .deb file of the packages matching the current
+ This function downloads .deb files of packages matching the amd64
architecture (which includes packages with architecture 'all') as well as